==> haskell-http-common-0.8.3.4-126-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-common
version:              0.8.3.4
visibility:           public
id:                   http-common-0.8.3.4-D0ONe4V2dP6DSeemWA7pIz
key:                  http-common-0.8.3.4-D0ONe4V2dP6DSeemWA7pIz
license:              BSD-3-Clause
copyright:            © 2012-2021 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  64042b33df4993aa4761afa036b29e1c
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/http-common-0.8.3.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http-common-0.8.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-common
hs-libraries:         HShttp-common-0.8.3.4-D0ONe4V2dP6DSeemWA7pIz
depends:
    base-4.15.1.0 base64-bytestring-1.2.1.0-88nOz7AP8GEI61ac5Ca3UI
    blaze-builder-0.4.2.3-D7RNQqfFzoeIMP5JYaknz9 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-6HwZPMiOaK97nwlWoHY1Gb directory-1.3.6.2
    mtl-2.2.2 network-3.1.4.0-23ur646Pq0yGXZtPd0ysVN
    random-1.2.1.1-8t6Qrrs5ZeF1jN6oGG3D31 text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-4LWMSZiig8M6j2saT8CDNm

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-common-0.8.3.4-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-common
version:              0.8.3.4
visibility:           public
id:                   http-common-0.8.3.4-2SncckLYnTO9Y7tj4GY9o4
key:                  http-common-0.8.3.4-2SncckLYnTO9Y7tj4GY9o4
license:              BSD-3-Clause
copyright:            © 2012-2021 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  a975bb5a2f69084fc7f0db3f04934a46
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/http-common-0.8.3.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http-common-0.8.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-common
hs-libraries:         HShttp-common-0.8.3.4-2SncckLYnTO9Y7tj4GY9o4
depends:
    base-4.15.1.0 base64-bytestring-1.2.1.0-CM0hYSNUcmEXJNyTXmK7o
    blaze-builder-0.4.2.3-D7RNQqfFzoeIMP5JYaknz9 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-EwGJMJdq8OSJtTSIf385Ig directory-1.3.6.2
    mtl-2.2.2 network-3.1.4.0-9Bfooq2NUZQBZiFYQuYMVQ
    random-1.2.1.1-Jsd8w3Sbg0mK17rOHVUzgD text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-J4eg8YowQRtEC3N7B7zfuy

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
